@@ -2,7 +2,10 @@
 
 #define _main_c_ 1
 
-/* Read the "COPYING" file for licensing terms. */
+/* This is copyrighted software.  Read the entire ``COPYRIGHT.h'' file
+ * before compiling or using!
+ */
+#include "COPYRIGHT.h"
 
 #include "Sys.h"
 
@@ -789,32 +792,18 @@ void StartupMsgs(void)
 	if ((gStartupMsgs & kStartupMsg) != 0) {
 #if (kAlpha > 0) || (kBeta > 0)
 		if (gWinInit == 0)
-			PrintF("NcFTP %s, by Mike Gleason.\n", gVersion);
+			PrintF("NcFTP %s, by Mike Gleason, NCEMRSoft.\n", gVersion);
 		BoldPrintF(
 		"This pre-release is for testing only.  Please do not archive.\n\n");
 		BoldPrintF(
 		"Check the CHANGELOG file for changes between betas.\n\n");
 #else
 		if (gWinInit == 0)
-			PrintF("NcFTP %s, by Mike Gleason.\n", gVersion);
+			PrintF("NcFTP %s, by Mike Gleason, NCEMRSoft.\n", gVersion);
 #endif
 	}
 	if (gTotalRuns < 2) {
-		PrintF("NcFTP is Copyright (C) 1992, Mike Gleason.  All rights reserved.\n\n");
-
-		PrintF("This program is free software; you can redistribute it and/or modify\n");
-		PrintF("it under the terms of the GNU General Public License as published by\n");
-		PrintF("the Free Software Foundation; either version 2 of the License, or\n");
-		PrintF("(at your option) any later version.\n\n");
-
-		PrintF("This program is distributed in the hope that it will be useful,\n");
-		PrintF("but WITHOUT ANY WARRANTY; without even the implied warranty of\n");
-		PrintF("MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n");
-		PrintF("GNU General Public License for more details.\n\n");
-
-		PrintF("You should have received a copy of the GNU General Public License\n");
-		PrintF("along with this program; if not, write to the Free Software\n");
-		PrintF("Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA\n\n");
+		PrintF("%s%s%s\n", gCopyright1 + 5, gCopyright2, gCopyright3);
 	} else if ((gStartupMsgs & kTips) != 0) {
 		PrintRandomTip();
 	}
