@@ -573,7 +573,7 @@ void SetDefaultBar(void)
 	if (gWinInit) {
 		STRNCPY(str, "NcFTP ");
 		STRNCAT(str, kVersion);
-		STRNCAT(str, " by Mike Gleason (mgleason@NcFTP.com).");
+		STRNCAT(str, " by Mike Gleason, NCEMRSoft (mgleason@probe.net).");
 		gUsingDefaultBar = 1;
 
 		SetBar("", str, "", 0, 0);
@@ -1043,14 +1043,15 @@ void MultiLinePrintF(char *fmt0, ...)
 	va_list ap;
 	char *fmt;
 
-	if (gVerbosity > kErrorsOnly) {
 #ifndef HAVE_STDARG_H
-		va_start(ap);
-		fmt = va_arg(ap, char *);
+	va_start(ap);
+	fmt = va_arg(ap, char *);
 #else
-		va_start(ap, fmt0);
-		fmt = fmt0;
+	va_start(ap, fmt0);
+	fmt = fmt0;
 #endif
+
+	if (gVerbosity > kErrorsOnly) {
 		if ((gWinInit) && (gRealStdout == gStdout)) {
 #ifdef USE_CURSES		
 			(void) vsprintf(gSprintfBuf, fmt, ap);
@@ -1060,21 +1061,13 @@ void MultiLinePrintF(char *fmt0, ...)
 			(void) vsprintf(gSprintfBuf, fmt, ap);
 			(void) write(gStdout, gSprintfBuf, strlen(gSprintfBuf));
 		}
-		va_end(ap);
 	}
 	if ((gTrace == kTracingOn) && (gTraceLogFile != NULL)) {
-#ifndef HAVE_STDARG_H
-		va_start(ap);
-		fmt = va_arg(ap, char *);
-#else
-		va_start(ap, fmt0);
-		fmt = fmt0;
-#endif
 		(void) vfprintf(gTraceLogFile, fmt, ap);
 		(void) fflush(gTraceLogFile);
-		va_end(ap);
 	}
 
+	va_end(ap);
 }	/* MultiLinePrintF */
 
 
@@ -1210,10 +1203,6 @@ void InitWindows(void)
 		WAttr(gBarWin, kReverse, 1);
 
 		getmaxyx(gListWin, maxy, maxx);
-		if (gScreenWidth > ((int) sizeof(string) - 1)) {
-			fprintf(stderr, "Visual mode for NcFTP only supports windows of %d columns or less.\nReduce your window size or use line mode (ncftp -L).\n", (int) sizeof(string) - 1);
-			Exit(kExitWinFail1);
-		}
 		gScreenWidth = maxx;
 
 		gBarLeft[0] = '\0';
